@@ -2,7 +2,7 @@ test_that("token works", {
   skip_if_offline()
   skip_if_no_auth()
 
-  expect_error_free(
+  expect_no_error(
     token <- credentials_service_account(
       scopes = "https://www.googleapis.com/auth/userinfo.email",
       path = rawToChar(secret_read("gargle", "gargle-testing.json"))
