@@ -1,28 +1,17 @@
 # cache_establish ------------------------------------------------------------
 
 test_that("cache_establish() insists on sensible input", {
-  expect_error(
-    cache_establish(letters[1:2]),
-    "must have length 1"
-  )
-  expect_error(
-    cache_establish(1),
-    class = "gargle_error_bad_class"
-  )
-  expect_error(
-    cache_establish(list(1)),
-    class = "gargle_error_bad_class"
-  )
+  expect_snapshot(cache_establish(letters[1:2]), error = TRUE)
+  expect_snapshot(cache_establish(1), error = TRUE)
+  expect_snapshot(cache_establish(list(1)), error = TRUE)
 })
 
 test_that("`cache = TRUE` uses default cache path", {
-  with_mock(
+  local_mocked_bindings(
     ## we don't want to actually initialize a cache
-    cache_create = function(path) NULL,
-    {
-      expect_equal(cache_establish(TRUE), gargle_default_oauth_cache_path())
-    }
+    cache_create = function(path) NULL
   )
+  expect_equal(cache_establish(TRUE), gargle_default_oauth_cache_path())
 })
 
 test_that("`cache = FALSE` does nothing", {
@@ -30,15 +19,13 @@ test_that("`cache = FALSE` does nothing", {
 })
 
 test_that("`cache = NA` is like `cache = FALSE` if cache not available", {
-  with_mock(
+  local_mocked_bindings(
     # we want no existing cache to be found, be it current or legacy
     gargle_default_oauth_cache_path = function() file_temp(),
     gargle_legacy_default_oauth_cache_path = function() file_temp(),
-    cache_allowed = function(path) FALSE,
-    {
-      expect_equal(cache_establish(NA), cache_establish(FALSE))
-    }
+    cache_allowed = function(path) FALSE
   )
+  expect_equal(cache_establish(NA), cache_establish(FALSE))
 })
 
 test_that("`cache = <filepath>` creates cache folder, recursively", {
@@ -67,25 +54,23 @@ test_that("`cache = <filepath>` adds new cache folder to relevant 'ignores'", {
 })
 
 test_that("default is to consult and set the oauth cache option", {
-  withr::with_options(
-    list(gargle_oauth_cache = NA),
-    with_mock(
-      # we want no existing cache to be found, be it current or legacy
-      gargle_default_oauth_cache_path = function() file_temp(),
-      gargle_legacy_default_oauth_cache_path = function() file_temp(),
-      cache_allowed = function(path) FALSE,
-      {
-        expect_equal(getOption("gargle_oauth_cache"), NA)
-        cache_establish()
-        expect_false(getOption("gargle_oauth_cache"))
-      }
-    )
+  withr::local_options(list(gargle_oauth_cache = NA))
+  local_mocked_bindings(
+    # we want no existing cache to be found, be it current or legacy
+    gargle_default_oauth_cache_path = function() file_temp(),
+    gargle_legacy_default_oauth_cache_path = function() file_temp(),
+    cache_allowed = function(path) FALSE
   )
+
+  expect_equal(getOption("gargle_oauth_cache"), NA)
+  cache_establish()
+  expect_false(getOption("gargle_oauth_cache"))
 })
 
 # cache_allowed() --------------------------------------------------------------
 
 test_that("cache_allowed() returns false when non-interactive (or testing)", {
+  local_interactive(FALSE)
   expect_false(cache_allowed(getwd()))
 })
 
@@ -220,6 +205,14 @@ test_that("token_match() returns NULL if no email and no short hash match", {
   expect_null(token_match("abc_*", "def_a@example.org"))
 })
 
+test_that("token_match() finds a match based on domain", {
+  one_match_of_two <- c("abc_jane@example.org", "abc_jane@gmail.com")
+  expect_snapshot(
+    m <- token_match("abc_*@example.org", one_match_of_two)
+  )
+  expect_equal(m, one_match_of_two[[1]])
+})
+
 test_that("token_match() scolds but returns short hash match when non-interactive", {
   local_interactive(FALSE)
 
@@ -324,6 +317,31 @@ test_that("gargle_oauth_sitrep() works with a cache", {
   )
 })
 
+test_that("gargle_oauth_sitrep() consults the option for cache location", {
+  tmp_cache <- file_temp()
+  withr::defer(dir_delete(tmp_cache))
+
+  gargle2.0_token(
+    email = "a@example.org",
+    credentials = list(a = 1),
+    cache = tmp_cache
+  )
+
+  withr::local_options(list(gargle_oauth_cache = tmp_cache))
+  local_gargle_verbosity("debug")
+  out <- capture.output(
+    gargle_oauth_sitrep(),
+    type = "message"
+  )
+  # bit of fiddliness to remove the volatile path and the hashes that can vary
+  # by OS
+  out <- sub(tmp_cache, "{path to gargle oauth cache}", out, fixed = TRUE)
+  out <- sub("[[:xdigit:]]{7}[.]{3}", "{hash...}", out)
+  expect_snapshot(
+    writeLines(out)
+  )
+})
+
 # helpers -----------------------------------------------------------
 
 test_that("match2() works", {
